from .AlignAverageWidget import AlignAverageWidget
from .AlignXYWidget import AlignXYWidget
from .AlignmentLineWidget import AlignmentLineWidget
from .BeadRecWidget import BeadRecWidget
from .ConsoleWidget import ConsoleWidget
from .EtSTEDWidget import EtSTEDWidget
from .FFTWidget import FFTWidget
from .FocusLockWidget import FocusLockWidget
from .AutofocusWidget import AutofocusWidget
from .ImageWidget import ImageWidget
from .LaserWidget import LaserWidget
from .PositionerWidget import PositionerWidget
from .RecordingWidget import RecordingWidget
from .SLMWidget import SLMWidget
from .ScanWidget import ScanWidget
from .SettingsWidget import SettingsWidget
from .ULensesWidget import ULensesWidget
from .WatcherWidget import WatcherWidget
from .ViewWidget import ViewWidget
from .TilingWidget import TilingWidget
from .basewidgets import WidgetFactory